@@ -28,7 +28,7 @@ def bulk_update(objs, update_fields=None, exclude_fields=None,
             for field in fields:
                 column = field.column
                 _default = SimpleLazyObject(
-                    lambda: '{column} = (CASE {pkcolumn} {{when}}'.format(
+                    lambda: '{column} = CAST(CASE {pkcolumn} {{when}}'.format(
                         column=column, pkcolumn=meta.pk.column))
 
                 case_clauses.setdefault(
@@ -37,14 +37,15 @@ def bulk_update(objs, update_fields=None, exclude_fields=None,
                              'type': field.db_type(connection)})
 
                 case_clauses[column]['sql'] = case_clauses[column]['sql']\
-                        .format(when="WHEN %s THEN %s {when}")
-   
+                    .format(when="WHEN %s THEN %s {when}")
+
                 case_clauses[column]['params'].extend(
-                    [obj.pk, getattr(obj, field.attname)])
+                    [obj.pk, field.get_db_prep_value(
+                        getattr(obj, field.attname), connection)])
 
         if pks:
             values = ', '.join(
-                map(lambda v: v['sql'].format(when=' END)::%s' % v['type']),
+                map(lambda v: v['sql'].format(when=' END AS %s)' % v['type']),
                     case_clauses.values()))
             paramaters = [item for v in case_clauses.values()
                           for item in v['params']]
